@@ -1,15 +1,12 @@
 # test-case-name: twisted.names.test.test_dns
-# Copyright (c) 2001-2007 Twisted Matrix Laboratories.
+# Copyright (c) Twisted Matrix Laboratories.
 # See LICENSE for details.
 
 """
 Tests for twisted.names.dns.
 """
 
-try:
-    from cStringIO import StringIO
-except ImportError:
-    from StringIO import StringIO
+from cStringIO import StringIO
 
 import struct
 
@@ -21,6 +18,171 @@ from twisted.names import dns
 
 from twisted.test import proto_helpers
 
+RECORD_TYPES = [
+    dns.Record_NS, dns.Record_MD, dns.Record_MF, dns.Record_CNAME,
+    dns.Record_MB, dns.Record_MG, dns.Record_MR, dns.Record_PTR,
+    dns.Record_DNAME, dns.Record_A, dns.Record_SOA, dns.Record_NULL,
+    dns.Record_WKS, dns.Record_SRV, dns.Record_AFSDB, dns.Record_RP,
+    dns.Record_HINFO, dns.Record_MINFO, dns.Record_MX, dns.Record_TXT,
+    dns.Record_AAAA, dns.Record_A6, dns.Record_NAPTR, dns.UnknownRecord,
+    ]
+
+class NameTests(unittest.TestCase):
+    """
+    Tests for L{Name}, the representation of a single domain name with support
+    for encoding into and decoding from DNS message format.
+    """
+    def test_decode(self):
+        """
+        L{Name.decode} populates the L{Name} instance with name information read
+        from the file-like object passed to it.
+        """
+        n = dns.Name()
+        n.decode(StringIO("\x07example\x03com\x00"))
+        self.assertEqual(n.name, "example.com")
+
+
+    def test_encode(self):
+        """
+        L{Name.encode} encodes its name information and writes it to the
+        file-like object passed to it.
+        """
+        name = dns.Name("foo.example.com")
+        stream = StringIO()
+        name.encode(stream)
+        self.assertEqual(stream.getvalue(), "\x03foo\x07example\x03com\x00")
+
+
+    def test_encodeWithCompression(self):
+        """
+        If a compression dictionary is passed to it, L{Name.encode} uses offset
+        information from it to encode its name with references to existing
+        labels in the stream instead of including another copy of them in the
+        output.  It also updates the compression dictionary with the location of
+        the name it writes to the stream.
+        """
+        name = dns.Name("foo.example.com")
+        compression = {"example.com": 0x17}
+
+        # Some bytes already encoded into the stream for this message
+        previous = "some prefix to change .tell()"
+        stream = StringIO()
+        stream.write(previous)
+
+        # The position at which the encoded form of this new name will appear in
+        # the stream.
+        expected = len(previous) + dns.Message.headerSize
+        name.encode(stream, compression)
+        self.assertEqual(
+            "\x03foo\xc0\x17",
+            stream.getvalue()[len(previous):])
+        self.assertEqual(
+            {"example.com": 0x17, "foo.example.com": expected},
+            compression)
+
+
+    def test_unknown(self):
+        """
+        A resource record of unknown type and class is parsed into an
+        L{UnknownRecord} instance with its data preserved, and an
+        L{UnknownRecord} instance is serialized to a string equal to the one it
+        was parsed from.
+        """
+        wire = (
+            '\x01\x00' # Message ID
+            '\x00' # answer bit, opCode nibble, auth bit, trunc bit, recursive
+                   # bit
+            '\x00' # recursion bit, empty bit, empty bit, empty bit, response
+                   # code nibble
+            '\x00\x01' # number of queries
+            '\x00\x01' # number of answers
+            '\x00\x00' # number of authorities
+            '\x00\x01' # number of additionals
+
+            # query
+            '\x03foo\x03bar\x00'    # foo.bar
+            '\xde\xad'              # type=0xdead
+            '\xbe\xef'              # cls=0xbeef
+
+            # 1st answer
+            '\xc0\x0c'              # foo.bar - compressed
+            '\xde\xad'              # type=0xdead
+            '\xbe\xef'              # cls=0xbeef
+            '\x00\x00\x01\x01'      # ttl=257
+            '\x00\x08somedata'      # some payload data
+
+            # 1st additional
+            '\x03baz\x03ban\x00'    # baz.ban
+            '\x00\x01'              # type=A
+            '\x00\x01'              # cls=IN
+            '\x00\x00\x01\x01'      # ttl=257
+            '\x00\x04'              # len=4
+            '\x01\x02\x03\x04'      # 1.2.3.4
+
+            )
+
+        msg = dns.Message()
+        msg.fromStr(wire)
+
+        self.assertEqual(msg.queries, [
+                dns.Query('foo.bar', type=0xdead, cls=0xbeef),
+                ])
+        self.assertEqual(msg.answers, [
+                dns.RRHeader('foo.bar', type=0xdead, cls=0xbeef, ttl=257,
+                             payload=dns.UnknownRecord('somedata', ttl=257)),
+                ])
+        self.assertEqual(msg.additional, [
+                dns.RRHeader('baz.ban', type=dns.A, cls=dns.IN, ttl=257,
+                             payload=dns.Record_A('1.2.3.4', ttl=257)),
+                ])
+
+        enc = msg.toStr()
+
+        self.assertEqual(enc, wire)
+
+
+    def test_decodeWithCompression(self):
+        """
+        If the leading byte of an encoded label (in bytes read from a stream
+        passed to L{Name.decode}) has its two high bits set, the next byte is
+        treated as a pointer to another label in the stream and that label is
+        included in the name being decoded.
+        """
+        # Slightly modified version of the example from RFC 1035, section 4.1.4.
+        stream = StringIO(
+            "x" * 20 +
+            "\x01f\x03isi\x04arpa\x00"
+            "\x03foo\xc0\x14"
+            "\x03bar\xc0\x20")
+        stream.seek(20)
+        name = dns.Name()
+        name.decode(stream)
+        # Verify we found the first name in the stream and that the stream
+        # position is left at the first byte after the decoded name.
+        self.assertEqual("f.isi.arpa", name.name)
+        self.assertEqual(32, stream.tell())
+
+        # Get the second name from the stream and make the same assertions.
+        name.decode(stream)
+        self.assertEqual(name.name, "foo.f.isi.arpa")
+        self.assertEqual(38, stream.tell())
+
+        # Get the third and final name
+        name.decode(stream)
+        self.assertEqual(name.name, "bar.foo.f.isi.arpa")
+        self.assertEqual(44, stream.tell())
+
+
+    def test_rejectCompressionLoop(self):
+        """
+        L{Name.decode} raises L{ValueError} if the stream passed to it includes
+        a compression pointer which forms a loop, causing the name to be
+        undecodable.
+        """
+        name = dns.Name()
+        stream = StringIO("\xc0\x00")
+        self.assertRaises(ValueError, name.decode, stream)
+
 
 
 class RoundtripDNSTestCase(unittest.TestCase):
@@ -38,7 +200,7 @@ class RoundtripDNSTestCase(unittest.TestCase):
             f.seek(0, 0)
             result = dns.Name()
             result.decode(f)
-            self.assertEquals(result.name, n)
+            self.assertEqual(result.name, n)
 
     def testQuery(self):
         for n in self.names:
@@ -52,9 +214,9 @@ class RoundtripDNSTestCase(unittest.TestCase):
                     f.seek(0, 0)
                     result = dns.Query()
                     result.decode(f)
-                    self.assertEquals(result.name.name, n)
-                    self.assertEquals(result.type, dnstype)
-                    self.assertEquals(result.cls, dnscls)
+                    self.assertEqual(result.name.name, n)
+                    self.assertEqual(result.type, dnstype)
+                    self.assertEqual(result.cls, dnscls)
 
     def testRR(self):
         # encode the RR
@@ -65,10 +227,10 @@ class RoundtripDNSTestCase(unittest.TestCase):
         f.seek(0, 0)
         result = dns.RRHeader()
         result.decode(f)
-        self.assertEquals(str(result.name), "test.org")
-        self.assertEquals(result.type, 3)
-        self.assertEquals(result.cls, 4)
-        self.assertEquals(result.ttl, 17)
+        self.assertEqual(str(result.name), "test.org")
+        self.assertEqual(result.type, 3)
+        self.assertEqual(result.cls, 4)
+        self.assertEqual(result.ttl, 17)
 
 
     def testResources(self):
@@ -85,26 +247,17 @@ class RoundtripDNSTestCase(unittest.TestCase):
             f.seek(0, 0)
             result = dns.SimpleRecord()
             result.decode(f)
-            self.assertEquals(str(result.name), s)
+            self.assertEqual(str(result.name), s)
 
     def test_hashable(self):
         """
         Instances of all record types are hashable.
         """
-        records = [
-            dns.Record_NS, dns.Record_MD, dns.Record_MF, dns.Record_CNAME,
-            dns.Record_MB, dns.Record_MG, dns.Record_MR, dns.Record_PTR,
-            dns.Record_DNAME, dns.Record_A, dns.Record_SOA, dns.Record_NULL,
-            dns.Record_WKS, dns.Record_SRV, dns.Record_AFSDB, dns.Record_RP,
-            dns.Record_HINFO, dns.Record_MINFO, dns.Record_MX, dns.Record_TXT,
-            dns.Record_AAAA, dns.Record_A6, dns.Record_NAPTR
-        ]
-
-        for k in records:
+        for k in RECORD_TYPES:
             k1, k2 = k(), k()
             hk1 = hash(k1)
             hk2 = hash(k2)
-            self.assertEquals(hk1, hk2, "%s != %s (for %s)" % (hk1,hk2,k))
+            self.assertEqual(hk1, hk2, "%s != %s (for %s)" % (hk1,hk2,k))
 
 
     def test_Charstr(self):
@@ -120,7 +273,7 @@ class RoundtripDNSTestCase(unittest.TestCase):
             f.seek(0, 0)
             result = dns.Charstr()
             result.decode(f)
-            self.assertEquals(result.string, n)
+            self.assertEqual(result.string, n)
 
 
     def test_NAPTR(self):
@@ -140,17 +293,21 @@ class RoundtripDNSTestCase(unittest.TestCase):
             e.seek(0,0)
             rout = dns.Record_NAPTR()
             rout.decode(e)
-            self.assertEquals(rin.order, rout.order)
-            self.assertEquals(rin.preference, rout.preference)
-            self.assertEquals(rin.flags, rout.flags)
-            self.assertEquals(rin.service, rout.service)
-            self.assertEquals(rin.regexp, rout.regexp)
-            self.assertEquals(rin.replacement.name, rout.replacement.name)
-            self.assertEquals(rin.ttl, rout.ttl)
+            self.assertEqual(rin.order, rout.order)
+            self.assertEqual(rin.preference, rout.preference)
+            self.assertEqual(rin.flags, rout.flags)
+            self.assertEqual(rin.service, rout.service)
+            self.assertEqual(rin.regexp, rout.regexp)
+            self.assertEqual(rin.replacement.name, rout.replacement.name)
+            self.assertEqual(rin.ttl, rout.ttl)
 
 
 
 class MessageTestCase(unittest.TestCase):
+    """
+    Tests for L{twisted.names.dns.Message}.
+    """
+
     def testEmptyMessage(self):
         """
         Test that a message which has been truncated causes an EOFError to
@@ -175,15 +332,15 @@ class MessageTestCase(unittest.TestCase):
             '\x00\x00' # number of authorities
             '\x00\x00' # number of additionals
             )
-        self.assertEquals(msg.id, 256)
+        self.assertEqual(msg.id, 256)
         self.failIf(msg.answer, "Message was not supposed to be an answer.")
-        self.assertEquals(msg.opCode, dns.OP_QUERY)
+        self.assertEqual(msg.opCode, dns.OP_QUERY)
         self.failIf(msg.auth, "Message was not supposed to be authoritative.")
         self.failIf(msg.trunc, "Message was not supposed to be truncated.")
-        self.assertEquals(msg.queries, [])
-        self.assertEquals(msg.answers, [])
-        self.assertEquals(msg.authority, [])
-        self.assertEquals(msg.additional, [])
+        self.assertEqual(msg.queries, [])
+        self.assertEqual(msg.answers, [])
+        self.assertEqual(msg.authority, [])
+        self.assertEqual(msg.additional, [])
 
 
     def testNULL(self):
@@ -199,7 +356,20 @@ class MessageTestCase(unittest.TestCase):
         msg2.decode(s)
 
         self.failUnless(isinstance(msg2.answers[0].payload, dns.Record_NULL))
-        self.assertEquals(msg2.answers[0].payload.payload, bytes)
+        self.assertEqual(msg2.answers[0].payload.payload, bytes)
+
+
+    def test_lookupRecordTypeDefault(self):
+        """
+        L{Message.lookupRecordType} returns C{dns.UnknownRecord} if it is
+        called with an integer which doesn't correspond to any known record
+        type.
+        """
+        # 65280 is the first value in the range reserved for private
+        # use, so it shouldn't ever conflict with an officially
+        # allocated value.
+        self.assertIdentical(
+            dns.Message().lookupRecordType(65280), dns.UnknownRecord)
 
 
 
@@ -250,7 +420,7 @@ class DatagramProtocolTestCase(unittest.TestCase):
         """
         self.proto.datagramReceived('',
             address.IPv4Address('UDP', '127.0.0.1', 12345))
-        self.assertEquals(self.controller.messages, [])
+        self.assertEqual(self.controller.messages, [])
 
 
     def test_simpleQuery(self):
@@ -258,13 +428,12 @@ class DatagramProtocolTestCase(unittest.TestCase):
         Test content received after a query.
         """
         d = self.proto.query(('127.0.0.1', 21345), [dns.Query('foo')])
-        self.assertEquals(len(self.proto.liveMessages.keys()), 1)
+        self.assertEqual(len(self.proto.liveMessages.keys()), 1)
         m = dns.Message()
         m.id = self.proto.liveMessages.items()[0][0]
         m.answers = [dns.RRHeader(payload=dns.Record_A(address='1.2.3.4'))]
-        called = False
         def cb(result):
-            self.assertEquals(result.answers[0].payload.dottedQuad(), '1.2.3.4')
+            self.assertEqual(result.answers[0].payload.dottedQuad(), '1.2.3.4')
         d.addCallback(cb)
         self.proto.datagramReceived(m.toStr(), ('127.0.0.1', 21345))
         return d
@@ -275,10 +444,10 @@ class DatagramProtocolTestCase(unittest.TestCase):
         Test that query timeouts after some seconds.
         """
         d = self.proto.query(('127.0.0.1', 21345), [dns.Query('foo')])
-        self.assertEquals(len(self.proto.liveMessages), 1)
+        self.assertEqual(len(self.proto.liveMessages), 1)
         self.clock.advance(10)
         self.assertFailure(d, dns.DNSQueryTimeoutError)
-        self.assertEquals(len(self.proto.liveMessages), 0)
+        self.assertEqual(len(self.proto.liveMessages), 0)
         return d
 
 
@@ -368,10 +537,10 @@ class DNSProtocolTestCase(unittest.TestCase):
         Test that query timeouts after some seconds.
         """
         d = self.proto.query([dns.Query('foo')])
-        self.assertEquals(len(self.proto.liveMessages), 1)
+        self.assertEqual(len(self.proto.liveMessages), 1)
         self.clock.advance(60)
         self.assertFailure(d, dns.DNSQueryTimeoutError)
-        self.assertEquals(len(self.proto.liveMessages), 0)
+        self.assertEqual(len(self.proto.liveMessages), 0)
         return d
 
 
@@ -380,13 +549,12 @@ class DNSProtocolTestCase(unittest.TestCase):
         Test content received after a query.
         """
         d = self.proto.query([dns.Query('foo')])
-        self.assertEquals(len(self.proto.liveMessages.keys()), 1)
+        self.assertEqual(len(self.proto.liveMessages.keys()), 1)
         m = dns.Message()
         m.id = self.proto.liveMessages.items()[0][0]
         m.answers = [dns.RRHeader(payload=dns.Record_A(address='1.2.3.4'))]
-        called = False
         def cb(result):
-            self.assertEquals(result.answers[0].payload.dottedQuad(), '1.2.3.4')
+            self.assertEqual(result.answers[0].payload.dottedQuad(), '1.2.3.4')
         d.addCallback(cb)
         s = m.toStr()
         s = struct.pack('!H', len(s)) + s
@@ -653,6 +821,26 @@ class ReprTests(unittest.TestCase):
             "<TXT data=['foo', 'bar'] ttl=15>")
 
 
+    def test_spf(self):
+        """
+        The repr of a L{dns.Record_SPF} instance includes the data and ttl
+        fields of the record.
+        """
+        self.assertEqual(
+            repr(dns.Record_SPF("foo", "bar", ttl=15)),
+            "<SPF data=['foo', 'bar'] ttl=15>")
+
+
+    def test_unknown(self):
+        """
+        The repr of a L{dns.UnknownRecord} instance includes the data and ttl
+        fields of the record.
+        """
+        self.assertEqual(
+            repr(dns.UnknownRecord("foo\x1fbar", 12)),
+            "<UNKNOWN data='foo\\x1fbar' ttl=12>")
+
+
 
 class _Equal(object):
     """
@@ -1185,16 +1373,60 @@ class EqualityTests(unittest.TestCase):
         """
         # Vary the length of the data
         self._equalityTest(
-            dns.Record_TXT(['foo', 'bar'], 10),
-            dns.Record_TXT(['foo', 'bar'], 10),
-            dns.Record_TXT(['foo', 'bar', 'baz'], 10))
+            dns.Record_TXT('foo', 'bar', ttl=10),
+            dns.Record_TXT('foo', 'bar', ttl=10),
+            dns.Record_TXT('foo', 'bar', 'baz', ttl=10))
         # Vary the value of the data
         self._equalityTest(
-            dns.Record_TXT(['foo', 'bar'], 10),
-            dns.Record_TXT(['foo', 'bar'], 10),
-            dns.Record_TXT(['bar', 'foo'], 10))
+            dns.Record_TXT('foo', 'bar', ttl=10),
+            dns.Record_TXT('foo', 'bar', ttl=10),
+            dns.Record_TXT('bar', 'foo', ttl=10))
         # Vary the ttl
         self._equalityTest(
-            dns.Record_TXT(['foo', 'bar'], 10),
-            dns.Record_TXT(['foo', 'bar'], 10),
-            dns.Record_TXT(['foo', 'bar'], 100))
+            dns.Record_TXT('foo', 'bar', ttl=10),
+            dns.Record_TXT('foo', 'bar', ttl=10),
+            dns.Record_TXT('foo', 'bar', ttl=100))
+
+
+    def test_spf(self):
+        """
+        L{dns.Record_SPF} instances compare equal if and only if they have the
+        same data and ttl.
+        """
+        # Vary the length of the data
+        self._equalityTest(
+            dns.Record_SPF('foo', 'bar', ttl=10),
+            dns.Record_SPF('foo', 'bar', ttl=10),
+            dns.Record_SPF('foo', 'bar', 'baz', ttl=10))
+        # Vary the value of the data
+        self._equalityTest(
+            dns.Record_SPF('foo', 'bar', ttl=10),
+            dns.Record_SPF('foo', 'bar', ttl=10),
+            dns.Record_SPF('bar', 'foo', ttl=10))
+        # Vary the ttl
+        self._equalityTest(
+            dns.Record_SPF('foo', 'bar', ttl=10),
+            dns.Record_SPF('foo', 'bar', ttl=10),
+            dns.Record_SPF('foo', 'bar', ttl=100))
+
+
+    def test_unknown(self):
+        """
+        L{dns.UnknownRecord} instances compare equal if and only if they have
+        the same data and ttl.
+        """
+        # Vary the length of the data
+        self._equalityTest(
+            dns.UnknownRecord('foo', ttl=10),
+            dns.UnknownRecord('foo', ttl=10),
+            dns.UnknownRecord('foobar', ttl=10))
+        # Vary the value of the data
+        self._equalityTest(
+            dns.UnknownRecord('foo', ttl=10),
+            dns.UnknownRecord('foo', ttl=10),
+            dns.UnknownRecord('bar', ttl=10))
+        # Vary the ttl
+        self._equalityTest(
+            dns.UnknownRecord('foo', ttl=10),
+            dns.UnknownRecord('foo', ttl=10),
+            dns.UnknownRecord('foo', ttl=100))
